from distutils.core import setup

setup(
	name			=	'CP6',
	version		    =	'1.0.0',
	py_modules		=	['CP6'],
	author			=	'Kevin Chen',
    author_email    =   'hchen66@ucsc.edu',
    url             =   'ucsc.edu',
	description		=	'CP6',
         )